@@ -21,25 +21,21 @@
 #ifndef vte_matcher_h_included
 #define vte_matcher_h_included
 
-#ident "$Id: matcher.h,v 1.4 2003/05/07 21:25:29 nalin Exp $"
 
 #include <glib-object.h>
+#include "vtetc.h"
 
 G_BEGIN_DECLS
 
 struct _vte_matcher;
 
-/* Create an initial matcher. */
-struct _vte_matcher *_vte_matcher_new(const char *emulation_hint);
+/* Create and init matcher. */
+struct _vte_matcher *_vte_matcher_new(const char *emulation,
+				      struct _vte_termcap *termcap);
 
 /* Free a matcher. */
 void _vte_matcher_free(struct _vte_matcher *matcher);
 
-/* Add a string to the matcher. */
-void _vte_matcher_add(struct _vte_matcher *matcher,
-		      const char *pattern, gssize length,
-		      const char *result, GQuark quark);
-
 /* Check if a string matches a sequence the matcher knows about. */
 const char *_vte_matcher_match(struct _vte_matcher *matcher,
 			       const gunichar *pattern, gssize length,
@@ -49,6 +45,9 @@ const char *_vte_matcher_match(struct _vte_matcher *matcher,
 /* Dump out the contents of a matcher, mainly for debugging. */
 void _vte_matcher_print(struct _vte_matcher *matcher);
 
+/* Free a parameter array. */
+void _vte_matcher_free_params_array(GValueArray *params);
+
 G_END_DECLS
 
 #endif
